@@ -182,7 +182,10 @@ class PreseemModel:
                 # Load the python modules for this model object type
                 pmod = import_module(f'preseem_protobuf.model.{name}_pb2')
                 gmod = import_module(f'preseem_protobuf.model.{name}_pb2_grpc')
-                stubcls = [x for x in dir(gmod) if x.endswith('Stub')][0]
+                stubs = [x for x in dir(gmod) if x.endswith('Stub')]
+                if not stubs:
+                    continue
+                stubcls = stubs[0]
                 svcstub = getattr(gmod, stubcls)(self._client._channel)
                 svcname = stubcls[:-11]  # trim "ServiceStub" from the name
 
